pub enum Annotation {
FileCitationAnnotation(FileCitationAnnotation),
FilePathAnnotation(FilePathAnnotation),
}Expand description
A citation within the message that points to a specific quote from a specific File associated with the assistant or the message. Generated when the assistant uses the “file_search” tool to search files.
Variants
FileCitationAnnotation(FileCitationAnnotation)
FilePathAnnotation(FilePathAnnotation)